@@ -3,18 +3,23 @@ from typing import List, Optional
 
 import click
 
+from robotcode.plugin import CommonConfig, pass_common_config
 from robotcode.plugin.manager import PluginManager
 
 from .__version__ import __version__
 
 
-@click.group(context_settings={"help_option_names": ["-h", "--help"]}, invoke_without_command=False)
+@click.group(
+    context_settings={"help_option_names": ["-h", "--help"], "auto_envvar_prefix": "ROBOTCODE"},
+    invoke_without_command=False,
+)
 @click.version_option(version=__version__, prog_name="robotcode")
 @click.option(
     "-c",
     "--config",
     "config_file",
     type=click.Path(exists=True, path_type=Path),
+    show_envvar=True,
     help="Config file to use.",
 )
 @click.option(
@@ -23,15 +28,23 @@ from .__version__ import __version__
     "profiles",
     type=str,
     multiple=True,
+    show_envvar=True,
     help="""\
         The Execution Profile to use. Can be specified multiple times.
-        If not specified, the default profile is used
+        If not specified, the default profile is used.
         """,
 )
-@click.option("-d", "--dry", is_flag=True, help="Dry run, do not execute any commands.")
+@click.option("-d", "--dry", is_flag=True, show_envvar=True, help="Dry run, do not execute any commands.")
+@click.option("-v", "--verbose", is_flag=True, help="Enables verbose mode.")
 @click.pass_context
+@pass_common_config
 def robotcode(
-    ctx: click.Context, config_file: Optional[Path], profiles: Optional[List[str]], dry: Optional[bool] = None
+    common_config: CommonConfig,
+    ctx: click.Context,
+    config_file: Optional[Path],
+    profiles: Optional[List[str]],
+    dry: bool = False,
+    verbose: bool = False,
 ) -> None:
     """\b
  _____       _           _    _____          _
@@ -42,10 +55,10 @@ def robotcode(
 |_|  \\_\\___/|_.__/ \\___/ \\__|\\_____\\___/ \\__,_|\\___|
 
 """
-    ctx.ensure_object(dict)
-    ctx.obj["config_file"] = config_file
-    ctx.obj["profiles"] = profiles
-    ctx.obj["dry"] = dry
+    common_config.config_file = config_file
+    common_config.profiles = profiles
+    common_config.dry = dry
+    common_config.verbose = verbose
 
 
 for p in PluginManager().cli_commands:
@@ -56,19 +69,19 @@ for p in PluginManager().cli_commands:
 @robotcode.command()
 @click.pass_context
 def debug(ctx: click.Context) -> None:
-    """Debug the robotframework run."""
+    """Debug a Robot Framework run."""
     click.echo("TODO")
 
 
 @robotcode.command()
 @click.pass_context
 def clean(ctx: click.Context) -> None:
-    """Clean the robotframework project."""
+    """Cleans a Robot Framework project."""
     click.echo("TODO")
 
 
 @robotcode.command()
 @click.pass_context
 def new(ctx: click.Context) -> None:
-    """Create a new robotframework project."""
+    """Create a new Robot Framework project."""
     click.echo("TODO")
